@@ -148,6 +148,26 @@ def get_variable_template():
         variable_template.append(["NVLIB64", f"{trtpy.nv_root}/lib64"])
     return variable_template
 
+def get_inv_variable_template():
+    variable_template = []
+    variable_template.append(["CPP_PKG", f"{trtpy.cpp_packages_root}"])
+    variable_template.append(["TRTPRO_INCLUDE", f"{trtpy.trtpy_root}/include"])
+    variable_template.append(["SYS_LIB", f"{trtpy.trtpy_root}/lib"])
+    variable_template.append(["PYTHON_LINK_NAME", f"{trtpy.pydll_link_name}"])
+    variable_template.append(["PYTHON_INCLUDE", f"{sys.exec_prefix}/include/{trtpy.pydll_link_name}"])
+    variable_template.append(["PYTHON_LIB", f"{trtpy.pydll_path}"])
+    
+    if trtpy.inited:
+        variable_template.append(["TRTPRO_LIB", f"{trtpy.libtrtpro_root}"])
+        variable_template.append(["CUDA_HOME", f"{trtpy.nv_root}"])
+        variable_template.append(["CUDA_INCLUDE", f"{trtpy.nv_root}/include/cuda"])
+        variable_template.append(["CUDNN_INCLUDE", f"{trtpy.nv_root}/include/cudnn"])
+        variable_template.append(["TENSORRT_INCLUDE", f"{trtpy.nv_root}/include/tensorRT"])
+        variable_template.append(["PROTOBUF_INCLUDE", f"{trtpy.nv_root}/include/protobuf"])
+        variable_template.append(["NVLIB64", f"{trtpy.nv_root}/lib64"])
+
+    variable_template = sorted(variable_template, key=lambda x:len(x[1]), reverse=True)
+    return variable_template
 
 def do_get_templ(args):
     from . import downloader
@@ -349,6 +369,27 @@ def do_env_source(args):
         open(save, "w").write(template_data)
         print(f"Save to {save}")
 
+def do_invert_variable(args):
+
+    trtpy.init(args.cuda, args.trt)
+    file_or_directory = args.file_or_directory
+    if not os.path.exists(file_or_directory):
+        print(f"No such file or directory, {file_or_directory}")
+        return 1
+
+    files = []
+    if os.path.isdir(file_or_directory):
+        for d, ds, fs in os.walk(file_or_directory):
+            files.extend([os.path.join(d, f) for f in fs])
+    else:
+        files.append(file_or_directory)
+
+    print("Replace project value to variable")
+    variable_template = get_inv_variable_template()
+    process_code_template.process_code_template(None, files, variable_template, process_code_template.inv_filter_content)
+    print("Done!")
+    return 0
+
 if __name__ == "__main__":
     do_if_exec()
     parser = argparse.ArgumentParser()
@@ -387,6 +428,11 @@ if __name__ == "__main__":
     p.add_argument("--cuda", type=str, help="cuda version, 10.2, 11.2, 10, 11 etc.", default=None)
     p.add_argument("--trt", type=str, help="trt version, 8.0, 8 etc.", default=None)
 
+    p = subp.add_parser("inv-vars", help="replace local file value invert to variables")
+    p.add_argument("file_or_directory", type=str, help=f"Project directory or file, file filter = {process_code_template.include_list}")
+    p.add_argument("--cuda", type=str, help="cuda version, 10.2, 11.2, 10, 11 etc.", default=None)
+    p.add_argument("--trt", type=str, help="trt version, 8.0, 8 etc.", default=None)
+
     p = subp.add_parser("mnist-test", help="test tensorrt with mnist")
     p.add_argument("--cuda", type=str, help="cuda version, 10.2, 11.2, 10, 11 etc.", default=None)
     p.add_argument("--trt", type=str, help="trt version, 8.0, 8 etc.", default=None)
@@ -408,7 +454,7 @@ if __name__ == "__main__":
     p.add_argument("--cuda", type=str, help="cuda version, 10.2, 11.2, 10, 11 etc.", default=None)
     p.add_argument("--trt", type=str, help="trt version, 8.0, 8 etc.", default=None)
 
-    p = subp.add_parser("env-source", help="try to load trtmodel file")
+    p = subp.add_parser("env-source", help="get trtpy environment")
     p.add_argument("--save", type=str, default="trtpy-environment.sh", help="save to file")
     p.add_argument("--print", action="store_true", help="print env path")
     p.add_argument("--cuda", type=str, help="cuda version, 10.2, 11.2, 10, 11 etc.", default=None)
@@ -427,7 +473,8 @@ if __name__ == "__main__":
         "prep-vars":     do_prep_vars,
         "compile":       do_compile,
         "tryload":       do_tryload,
-        "env-source":    do_env_source
+        "env-source":    do_env_source,
+        "inv-vars":      do_invert_variable
     }
 
     if args.cmd in cmd_funcs:
